package ucot.core;

import java.util.List;
import java.util.Observable;
import java.util.Observer;
import java.util.Vector;
import java.util.logging.Logger;

import ucot.model.AnalyzeModel;
import ucot.model.Updation;

/**
 * <pre>public class <b>AnalyzeModelLogger</b><br />implements Observer</pre>
 * 
 * <p>Class for logging changes in current analyze model. The changes
 * are observed and  the log is updated every time the analyze model
 * notifies all observers about its changes.</p>
 * 
 * @see #java.util.Observer
 * @author pajumasu
 */
public class AnalyzeModelLogger implements Observer {
	
	private Logger logger = Logger.getLogger("ucot.model");
	private List<Updation> updations = new Vector<Updation>();
	
	/**
	 * <p>This method updates the logger when something
	 * changes in the analyze model.</p>
	 * 
	 * @param observable Observable object, in this case
	 *   the analyze model.
	 * @param arg Arguments for this method. If this
	 *   is not an instance of Updation, then this method
	 *   will do nothing.
	 */
	public void update(Observable observable, Object arg) {
		// We observe only analyse models.
		if ( !(observable instanceof AnalyzeModel) ) return;
		
		// We observer only updation messages
		if ( !(arg instanceof Updation) ) return;
		
		Updation updation = (Updation) arg;
		
		String[] references = updation.getReferences();
		StringBuffer stringBuffer = new StringBuffer();
		stringBuffer.append("[");
		for( String str : references ){
			stringBuffer.append(str);
			stringBuffer.append(",");
		}
		
		if ( stringBuffer.length() > 1 ) {
			stringBuffer.setLength(stringBuffer.length()-1);
		}
		stringBuffer.append("]");
		logger.info(updation.getType() + " " + updation.getDataType() +
				" " + stringBuffer.toString());
		updations.add(updation);		
	}
	
}
