package ucot.test;

import java.net.URL;

import junit.framework.Assert;
import junit.framework.TestCase;

import org.junit.Test;

import ucot.heuristic.AbbottsHeuristic;
import ucot.input.SimpleInputAdapter;
import ucot.input.UseCaseCollection;
import ucot.model.AnalyzeModel;
import ucot.model.object.ObjectAnalyzeModel;
import ucot.parser.ParsedData;
import ucot.parser.SimpleInputParser;

/**
 * This class implements test for the heuristics.
 * @author tujupien
 */
public class HeuristicTest extends TestCase {
	
    final String testFileName = "Core-SimpleInputAdapter-UseCases-Test.txt";
    
    /**
     * This method tests Abbott's heuristic module and its initialization.
     * It is up to the tester to confirm that the heuristic gives correct
     * output.
     */
    @Test
	public void testAbbottsHeuristic() {
        System.out.println("TEST: Testing Abbott's Heuristic.");
        
        URL file;
        // Try to initialize test file URL.
        try {
            file = new URL("file", "", -1, testFileName);        
        } catch (Exception e) {
            System.out.println("TEST: Failed to initialize AbbottsHeuristic test. Stage 1.");
            e.printStackTrace();
            Assert.fail();
            return;
        }
        // Initialize simple input adapter and load use cases.
        SimpleInputAdapter sia = new SimpleInputAdapter();
        UseCaseCollection collection;
        try {
            collection = sia.read(file);
        } catch (Exception e) {
            System.out.println("TEST: Failed to initialize AbbottsHeuristic test. Stage 2.");
            e.printStackTrace();
            Assert.fail();
            return;
        }
        // Initialize simple input parser and parse data.
        SimpleInputParser sip = new SimpleInputParser();
        ParsedData data;
        try {
            data = sip.parse(collection.getUseCase(0));
        } catch (Exception e) {
            System.out.println("TEST: Failed to initialize AbbottsHeuristic test. Stage 3.");
            e.printStackTrace();
            Assert.fail();
            return;
        }
        
        // Initialize heuristic module and do heuristic to the
        // parsed data.
        AnalyzeModel model = new ObjectAnalyzeModel();
        AbbottsHeuristic heuristic = new AbbottsHeuristic();
        try {
            heuristic.doHeuristic(data, model);
        } catch (Exception e) {
            System.out.println("TEST: AbbottsHeuristic failed.");
            System.out.println("TEST: -- " + e.getMessage());
            Assert.fail();
            return;
        }
        
        // TODO ADD Validation for the test data
	}

}
