package ucot.ui;

import java.util.logging.Logger;

import ucot.Messages;
import ucot.ModuleProperties;
import ucot.core.ControlInterface;
import ucot.core.DummyProgressBar;

/**
 * DummyUI which does absolutely nothing but helps avoiding
 * null values in UI variables. Errors and warnings do get logged.
 * 
 * @author UCOT
 */
public class DummyUI extends ModuleProperties implements UIInterface {

	public static final String DEFAULT_ERROR_TITLE =
		Messages.getString("UI.DEFAULT_ERROR_TITLE");
	public static final String DEFAULT_WARNING_TITLE =
		Messages.getString("UI.DEFAULT_WARNING_TITLE");
	private Logger logger = Logger.getLogger("ucot.ui");
	
	/* (non-Javadoc)
	 * @see ucot.ui.UIInterface#exportDone()
	 */
	public void exportDone() {}
	
	/* (non-Javadoc)
	 * @see ucot.ui.UIInterface#analyzeModelLoaded()
	 */
	public void analyzeModelLoaded() {}
	
	/* (non-Javadoc)
	 * @see ucot.ui.UIInterface#useCasesLoaded()
	 */
	public void useCasesLoaded() {}
	
	/* (non-Javadoc)
	 * @see ucot.ui.UIInterface#useCaseAdded()
	 */
	public void useCaseAdded() {}
	
	/* (non-Javadoc)
	 * @see ucot.ui.UIInterface#setControlInterface(ucot.core.ControlInterface)
	 */
	public void setControlInterface(ControlInterface a) {}
	
	/* (non-Javadoc)
	 * @see ucot.ui.UIInterface#printError(java.lang.String, java.lang.String)
	 */
	public void printError(String errorMessage, String errorTitle) {
		logger.severe(errorTitle + ": " + errorMessage);
	}
	
	/* (non-Javadoc)
	 * @see ucot.ui.UIInterface#printError(java.lang.String)
	 */
	public void printError(String errorMessage) {
		printError(errorMessage, DEFAULT_ERROR_TITLE);
	}
	
	/* (non-Javadoc)
	 * @see ucot.ui.UIInterface#printWarning(java.lang.String, java.lang.String)
	 */
	public void printWarning(String warningMessage, String warningTitle) {
		logger.warning(warningTitle + ": " + warningMessage);
	}
	
	/* (non-Javadoc)
	 * @see ucot.ui.UIInterface#printWarning(java.lang.String)
	 */
	public void printWarning(String warningMessage) {
		printWarning(warningMessage, DEFAULT_WARNING_TITLE);
	}
	
	/* (non-Javadoc)
	 * @see ucot.ui.UIInterface#getProgressBar()
	 */
	public ProgressBarInterface getProgressBar() { return new DummyProgressBar(); }

}
