package ucot.ui.gui.dot;

/**
 * Class that implements a color model used in dot graph drawing
 * environment. This model can be used for both main colors
 * and highlights.
 * 
 * @author UCOT
 */
public class DotColorModel {
	
	//TODO comment me
	public static enum ColorModel {BLACK_ON_WHITE,
								   WHITE_ON_BLACK,
								   GREEN,
								   BLUE,
								   RED};
	private String edgeColor = "";
	private String fillColor = "";
	private String fontColor = "";
	private ColorModel model;
	
	/**
	 * Constructor which sets all the colors as specified.
	 * @param edgeColor Color of edges in the graph.
	 * @param fillColor Color for filling the elements on the graph.
	 *   Can also be used for graph background.
	 * @param fontColor Text color.
	 */
	private DotColorModel(String edgeColor, String fillColor, String fontColor) {
		this.edgeColor = edgeColor;
		this.fillColor = fillColor;
		this.fontColor = fontColor;
	}
	
	/**
	 * Constructor for quick color model initialization.
	 * @param drawColor Color for all edges and text in the graph.
	 * @param fillColor Background color for the whole graph and
	 *   all elements.
	 */
	private DotColorModel(String drawColor, String fillColor) {
		this(drawColor, fillColor, drawColor);
	}
	
	/**
	 * Method for acquiring the edge color.
	 * @return Edge color.
	 */
	public String getEdgeColor() {
		return edgeColor;
	}
	
	/**
	 * Method for acquiring the fill color.
	 * @return Fill color.
	 */
	public String getFillColor() {
		return fillColor;
	}
	
	/**
	 * Method for acquiring the font color.
	 * @return Font color.
	 */
	public String getFontColor() {
		return fontColor;
	}
	
	/**
	 * Method for acquiring the name of the current model.
	 * @return Color model's name.
	 */
	public String getModel() {
		return model.toString();
	}
	
	/**
	 * This static method creates a blue dot color model.
	 * @return Blue dot color model.
	 */
	private static DotColorModel blue() {
		DotColorModel result = new DotColorModel("dodgerblue", "lightblue");
		result.model = ColorModel.BLUE;
		return result;
	}
	
	/**
	 * This static method creates a green dot color model.
	 * @return Green dot color model.
	 */
	private static DotColorModel green() {
		DotColorModel result = new DotColorModel("forestgreen", "chartreuse");
		result.model = ColorModel.GREEN;
		return result;
	}
	
	/**
	 * This static method creates a black text on white background dot color model.
	 * @return Black text on white background dot color model.
	 */
	private static DotColorModel blackOnWhite() {
		DotColorModel result = new DotColorModel("black", "white");
		result.model = ColorModel.BLACK_ON_WHITE;
		return result;
	}
	
	/**
	 * This static method creates a white text on black background dot color model.
	 * @return White text on black background dot color model.
	 */
	private static DotColorModel whiteOnBlack() {
		DotColorModel result = new DotColorModel("white", "black");
		result.model = ColorModel.WHITE_ON_BLACK;
		return result;
	}
	
	/**
	 * This static method creates a red dot color model.
	 * @return Red dot color model.
	 */
	private static DotColorModel red() {
		DotColorModel result = new DotColorModel("firebrick", "tomato");
		result.model = ColorModel.RED;
		return result;
	}
	
	// TODO Add more color models.
	
	/**
	 * Static method for creating a color model from available sets.
	 */
	public static DotColorModel color(ColorModel colorModel) {
		switch (colorModel) {
			case BLUE: return blue();
			case GREEN: return green();
			case BLACK_ON_WHITE: return blackOnWhite();
			case WHITE_ON_BLACK: return whiteOnBlack();
			case RED: return red();
			default: return blackOnWhite();
		}
	}
	
	/**
	 * Static method for creating a color model from available sets.
	 */
	public static DotColorModel color(String colorModel) {
		return color(ColorModel.valueOf(colorModel));
	}
}
